Module blaxel.core.client.models.metrics
========================================

Classes
-------

`Metrics(agents: blaxel.core.client.types.Unset | Any = <blaxel.core.client.types.Unset object>, functions: blaxel.core.client.types.Unset | Any = <blaxel.core.client.types.Unset object>, inference_global: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, items: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, last_n_requests: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, models: blaxel.core.client.types.Unset | ForwardRef('MetricsModels') = <blaxel.core.client.types.Unset object>, request_total: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, request_total_per_code: blaxel.core.client.types.Unset | ForwardRef('MetricsRequestTotalPerCode') = <blaxel.core.client.types.Unset object>, rps: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, rps_per_code: blaxel.core.client.types.Unset | ForwardRef('MetricsRpsPerCode') = <blaxel.core.client.types.Unset object>, sandboxes: blaxel.core.client.types.Unset | Any = <blaxel.core.client.types.Unset object>)`
:   Metrics for resources
    
    Attributes:
        agents (Union[Unset, Any]): Metrics for agents
        functions (Union[Unset, Any]): Metrics for functions
        inference_global (Union[Unset, list[Any]]): Historical requests for all resources globally
        items (Union[Unset, list[Any]]): Historical requests for all resources globally
        last_n_requests (Union[Unset, int]): Metric value
        models (Union[Unset, MetricsModels]): Metrics for models
        request_total (Union[Unset, float]): Number of requests for all resources globally
        request_total_per_code (Union[Unset, MetricsRequestTotalPerCode]): Number of requests for all resources globally
            per code
        rps (Union[Unset, float]): Number of requests per second for all resources globally
        rps_per_code (Union[Unset, MetricsRpsPerCode]): Number of requests per second for all resources globally per
            code
        sandboxes (Union[Unset, Any]): Metrics for sandboxes
    
    Method generated by attrs for class Metrics.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `agents`
    :

    `functions`
    :

    `inference_global`
    :

    `items`
    :

    `last_n_requests`
    :

    `models`
    :

    `request_total`
    :

    `request_total_per_code`
    :

    `rps`
    :

    `rps_per_code`
    :

    `sandboxes`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :